package HTFeed::Namespace::UMN;
use strict;
use warnings;
use HTFeed::Namespace ;
use base qw(HTFeed::Namespace);

# The HathiTrust namespace
our $identifier = 'umn';

our $config = {

    # The GRIN ID
    grinid => 'MINN',
    packagetypes => [qw(ht google)],

    handle_prefix => '2027/umn',
    description => 'University of Minnesota',

    tags => [qw(bib cic pd_only report)]
};


sub validate_barcode {
    my $self    = shift;
    my $barcode = shift;

    my $count;
    my $position = 0;
    my $sum = 0;
    my $mult;
    my $char;

    # Must be 15 chars and start with 31951
    if($barcode !~ /^31951[a-z0-9]{10}$/) {
	return;
    }

    $barcode =~ tr/a-z/A-Z/;                # convert letters to caps for ord
    my @chars = split(//, $barcode);        # split $barcode into array
					    # convert letters to numbers
    foreach $char(@chars) {
	    if(ord($char) - 65 >=0) {
		    $char = ord($char) - 55
	    }
    }

    my $check = substr($barcode, (length($barcode)-1),1);   # get check digit
    my $drop = pop(@chars);                                 # remove check digit
							    # get sum of values by position
    foreach $char (@chars) {
	    $position = $position + 1;
	    $count = (-15 + (($position)-1));
	    $mult = $count * $char;
	    $sum = $sum + $mult;
    }

    my $mod = ($sum % 36);

    if($mod > 9) {
	    $mod = chr($mod + 55);
    }


    if ($check eq $mod) {
	    return 1;
    }   else {
	    return;
    }

}

1;

__END__

=pod

This is the namespace configuration file for the University of Minnesota.

=head1 SYNOPSIS

use HTFeed::Namespace;

my $namespace = new HTFeed::Namespace('umn');

=head1 AUTHOR

Aaron Elkiss, University of Michigan, aelkiss@umich.edu

=head1 COPYRIGHT

Copyright (c) 2010 University of Michigan. All rights reserved.  This program
is free software; you can redistribute it and/or modify it under the same terms
as Perl itself.

=cut
