package HTFeed::Namespace::USU;

use strict;
use warnings;
use HTFeed::Namespace ;
use HTFeed::XPathValidator qw(:closures);
use base qw(HTFeed::Namespace);

# The HathiTrust namespace
our $identifier = 'usu';

our $config = {

    # The GRIN ID

    packagetypes => [qw(ump)],
    description => 'Utah State University',

    handle_prefix => '2027/usu',

    validation => {
      'HTFeed::ModuleValidator::JPEG2000_hul' => {
          'layers' => v_eq( 'codingStyleDefault', 'layers', '8' ),
      }
    }

};


# Expected barcodes: 39060NNNNNNNN
# Some Bentley barcodes are broken in a predictable but very unusual way, see
# below.

sub validate_barcode {
    my $self    = shift;
    my $barcode = shift;
    return $self->luhn_is_valid( '39060', $barcode); 
}

1;
__END__

=pod

This is the namespace configuration file for Utah State University

=head1 SYNOPSIS

use HTFeed::Namespace;

my $namespace = new HTFeed::Namespace('usu');

=head1 AUTHOR

Aaron Elkiss, University of Michigan, aelkiss@umich.edu

=head1 COPYRIGHT

Copyright (c) 2011 University of Michigan. All rights reserved.  This program
is free software; you can redistribute it and/or modify it under the same terms
as Perl itself.

=cut
