package HTFeed::PackageType::Google::Volume;

use strict;
use warnings;
use HTFeed::Volume;
use base qw(HTFeed::Volume);

sub get_page_data {
    my $self = shift;
    my $file = shift;

    (my $seqnum) = ($file =~ /(\d+)\./);
    croak("Can't extract sequence number from file $file") unless $seqnum;

    if(not defined $self->{'page_data'}) {
        my $pagedata = {};

        my $xc = $self->get_source_mets_xpc();
        foreach my $page ($xc->findnodes('//METS:structMap/METS:div/METS:div')) {
            my $order = sprintf("%08d",$page->getAttribute('ORDER'));
            my $detected_pagenum = $page->getAttribute('ORDERLABEL');
            my $tags = $page->getAttribute('ADMID');
            # Google tags are space delimited; we want comma-delimited
            if (defined $tags) {
                $tags = join(', ',split(/\s/,$tags));
            }
            $pagedata->{$order} = {
                orderlabel => $detected_pagenum,
                label => $tags
            }
        }
        $self->{page_data} = $pagedata;
    }

    return $self->{page_data}{$seqnum};
}

sub is_digifeed {
    my $self = shift;

    my $xc = $self->get_source_mets_xpc();

    # Consider the volume a digifeed if the 'digital feed' image method is
    # present, even if other image methods are also present
    foreach my $image_method ($xc->findnodes('//gbs:imageMethod')) {
        if($image_method->textContent() eq 'digital feed') {
            return 1;
        }
    }

    return 0;
}

1;
